@@ -85,16 +85,6 @@ UNBUILDABLE_IMAGES = {
         "skydive-base",      # no aarch64 binary
     },
 
-    'ppc64le': {
-        "elasticsearch",     # no binary package
-        "grafana",           # no binary package
-        "monasca-grafana",   # no phantomJS
-        "prometheus-base",   # no ppc64le binaries
-        "skydive-base",      # no ppc64le binaries
-        "telegraf",          # no binary package
-        "xtrabackup",        # no binary package
-    },
-
     'binary': {
         "bifrost-base",
         "blazar-base",
@@ -108,18 +98,6 @@ UNBUILDABLE_IMAGES = {
         "zun-base",
     },
 
-    'source+aarch64': {
-        "monasca-base",  # pypi 'confluent-kafka' requires newer libfdkafka-dev
-                         # than distributions have
-        "tempest",       # same reason as 'monasca-base'
-    },
-
-    'source+ppc64le': {
-        "monasca-base",  # pypi 'confluent-kafka' requires newer libfdkafka-dev
-                         # than distributions have
-        "tempest",       # same reason as 'monasca-base'
-    },
-
     'centos': {
         "hacluster-pcs",         # Missing crmsh package
         "nova-spicehtml5proxy",  # Missing spicehtml5 package
@@ -129,32 +107,33 @@ UNBUILDABLE_IMAGES = {
 
     'debian': {
         "bifrost-base",  # tries to install 'mysql-server' which is not in
-                         # Debian 'buster'
-        "ovn-base",      # needs more checking
-        "qdrouterd",
+                         # Debian 'buster' (fixed in Yoga)
+        "qdrouterd",     # no qdrouterd package in Debian bullseye
     },
 
     'ubuntu': {
-        "qdrouterd",  # There is no qdrouterd package for ubuntu bionic
+        "qdrouterd",  # There is no qdrouterd package for Ubuntu
+    },
+
+    'debian+aarch64': {
+        "ovn-base",      # no binary package
     },
 
     'ubuntu+aarch64': {
         "kibana",        # no binary package
+        "monasca-base",  # 'confluent-kafka' requires newer libfdkafka-dev
+                         # than distribution has
     },
 
     'centos+aarch64': {
         "hacluster-pcs",  # no binary package
         "influxdb",       # no binary package
         "kibana",         # no binary package
+        "monasca-base",   # 'confluent-kafka' requires newer libfdkafka-dev
+                          # than distribution has
         "telegraf",       # no binary package
     },
 
-    'centos+ppc64le': {
-        "hacluster-pcs",  # no binary package
-        "influxdb",       # no binary package
-        "kibana",         # no binary package
-    },
-
     "centos+binary": {
         "masakari-base",
     },
@@ -165,8 +144,6 @@ UNBUILDABLE_IMAGES = {
     },
 
     'ubuntu+binary': {
-        "cloudkitty-base",  # no binary packages in UCA
-        "rally",
         "senlin-conductor",  # no binary package
         "senlin-health-manager",  # no binary package
         "tacker-base",
@@ -332,14 +309,9 @@ class PushTask(DockerTask):
 
         # Since docker 3.0.0, the argument of 'insecure_registry' is removed.
         # To be compatible, set 'insecure_registry=True' for old releases.
-        # NOTE(frickler): The version check will fail for docker >= 6.0, but
-        # in that case we know that the workaround isn't needed.
-        try:
-            dc_running_ver = StrictVersion(docker.version)
-            if dc_running_ver < StrictVersion('3.0.0'):
-                kwargs['insecure_registry'] = True
-        except TypeError:
-            pass
+        dc_running_ver = StrictVersion(docker.version)
+        if dc_running_ver < StrictVersion('3.0.0'):
+            kwargs['insecure_registry'] = True
 
         for response in self.dc.push(image.canonical_name, **kwargs):
             if 'stream' in response:
@@ -393,15 +365,6 @@ class BuildTask(DockerTask):
     def process_source(self, image, source):
         dest_archive = os.path.join(image.path, source['name'] + '-archive')
 
-        # NOTE(mgoddard): Change ownership of files to root:root. This
-        # avoids an issue introduced by the fix for git CVE-2022-24765,
-        # which breaks PBR when the source checkout is not owned by the
-        # user installing it. LP#1969096
-        def reset_userinfo(tarinfo):
-            tarinfo.uid = tarinfo.gid = 0
-            tarinfo.uname = tarinfo.gname = "root"
-            return tarinfo
-
         if source.get('type') == 'url':
             self.logger.debug("Getting archive from %s", source['source'])
             try:
@@ -447,8 +410,7 @@ class BuildTask(DockerTask):
                 return
 
             with tarfile.open(dest_archive, 'w') as tar:
-                tar.add(clone_dir, arcname=os.path.basename(clone_dir),
-                        filter=reset_userinfo)
+                tar.add(clone_dir, arcname=os.path.basename(clone_dir))
 
         elif source.get('type') == 'local':
             self.logger.debug("Getting local archive from %s",
@@ -456,8 +418,7 @@ class BuildTask(DockerTask):
             if os.path.isdir(source['source']):
                 with tarfile.open(dest_archive, 'w') as tar:
                     tar.add(source['source'],
-                            arcname=os.path.basename(source['source']),
-                            filter=reset_userinfo)
+                            arcname=os.path.basename(source['source']))
             else:
                 shutil.copyfile(source['source'], dest_archive)
 
@@ -681,15 +642,12 @@ class KollaWorker(object):
         self.base_tag = conf.base_tag
         self.install_type = conf.install_type
         self.tag = conf.tag
-        self.repos_yaml = conf.repos_yaml
         self.base_arch = conf.base_arch
         self.debian_arch = self.base_arch
         if self.base_arch == 'aarch64':
             self.debian_arch = 'arm64'
         elif self.base_arch == 'x86_64':
             self.debian_arch = 'amd64'
-        elif self.base_arch == 'ppc64le':
-            self.debian_arch = 'ppc64el'
         self.images = list()
         self.openstack_release = conf.openstack_release
         self.docker_healthchecks = conf.docker_healthchecks
@@ -697,59 +655,29 @@ class KollaWorker(object):
                              conf.rpm_setup_config if repo_file is not None])
         self.rpm_setup = self.build_rpm_setup(rpm_setup_config)
 
-        rh_base = ['centos', 'rhel']
-        rh_type = ['source', 'binary', 'rdo', 'rhos']
-        deb_base = ['ubuntu', 'debian']
-        deb_type = ['source', 'binary']
-
-        if self.base in rh_base:
+        if self.base in ['centos']:
             self.conf.distro_python_version = "3.6"
+            self.distro_package_manager = 'dnf'
+            self.base_package_type = 'rpm'
         elif self.base in ['debian']:
             self.conf.distro_python_version = "3.9"
+            self.distro_package_manager = 'apt'
+            self.base_package_type = 'deb'
         elif self.base in ['ubuntu']:
             self.conf.distro_python_version = "3.8"
+            self.distro_package_manager = 'apt'
+            self.base_package_type = 'deb'
         else:
             # Assume worst
             self.conf.distro_python_version = "3.6"
 
         if self.conf.distro_package_manager is not None:
-            package_manager = self.conf.distro_package_manager
-        elif self.base in rh_base:
-            package_manager = 'dnf'
-        elif self.base in deb_base:
-            package_manager = 'apt'
-        self.distro_package_manager = package_manager
+            self.distro_package_manager = self.conf.distro_package_manager
 
-        self.clean_package_cache = self.conf.clean_package_cache
-
-        # Determine base packaging type for use in Dockerfiles.
         if self.conf.base_package_type:
             self.base_package_type = self.conf.base_package_type
-        elif self.base in rh_base:
-            self.base_package_type = 'rpm'
-        elif self.base in deb_base:
-            self.base_package_type = 'deb'
 
-        if not ((self.base in rh_base and self.install_type in rh_type) or
-                (self.base in deb_base and self.install_type in deb_type)):
-            raise exception.KollaMismatchBaseTypeException(
-                '{} is unavailable for {}'.format(self.install_type, self.base)
-            )
-
-        if self.install_type == 'binary':
-            self.install_metatype = 'rdo'
-        elif self.install_type == 'source':
-            self.install_metatype = 'mixed'
-        elif self.install_type == 'rdo':
-            self.install_type = 'binary'
-            self.install_metatype = 'rdo'
-        elif self.install_type == 'rhos':
-            self.install_type = 'binary'
-            self.install_metatype = 'rhos'
-        else:
-            raise exception.KollaUnknownBuildTypeException(
-                'Unknown install type'
-            )
+        self.clean_package_cache = self.conf.clean_package_cache
 
         if (self.install_type == 'binary' and self.base == 'debian' and
                 self.base_arch != 'x86_64'):
@@ -940,13 +868,11 @@ class KollaWorker(object):
                       'base_image': self.conf.base_image,
                       'base_distro_tag': self.base_tag,
                       'base_arch': self.base_arch,
-                      'repos_yaml': self.repos_yaml,
                       'use_dumb_init': self.use_dumb_init,
                       'base_package_type': self.base_package_type,
                       'debian_arch': self.debian_arch,
                       'docker_healthchecks': self.docker_healthchecks,
                       'supported_distro_name': supported_distro_name,
-                      'install_metatype': self.install_metatype,
                       'image_prefix': self.image_prefix,
                       'infra_image_prefix': self.infra_image_prefix,
                       'install_type': self.install_type,
@@ -1488,13 +1414,13 @@ def run_build():
         try:
             for x in range(conf.threads):
                 worker = WorkerThread(conf, build_queue)
-                worker.setDaemon(True)
+                worker.daemon = True
                 worker.start()
                 workers.append(worker)
 
             for x in range(conf.push_threads):
                 worker = WorkerThread(conf, push_queue)
-                worker.setDaemon(True)
+                worker.daemon = True
                 worker.start()
                 workers.append(worker)
 
