@@ -42,40 +42,11 @@ TARGET = '.releases'
 SKIP_PROJECTS = {
     'gnocchi-base': 'Gnocchi is not managed by openstack/releases project',
     'monasca-thresh': 'Package not published in tarballs.openstack.org',
-    'neutron-base-plugin-vmware-nsx': 'vmware-nsx is not managed by '
-                                      'openstack/releases project (need to '
-                                      'check PyPI, they sync major versions '
-                                      'with neutron)',
-    'rally': 'Rally is not managed by openstack/releases project',
 }
 
 # NOTE(hrw): those projects we take as they are they may have just one old
 # release or no stable branch tarballs
 ALWAYS_USE_VERSION_PROJECTS = {
-    'barbican_tempest_plugin',
-    'blazar_tempest_plugin',
-    'cinder-tempest-plugin',
-    'ec2api-tempest-plugin',
-    'heat-tempest-plugin',
-    'ironic-tempest-plugin',
-    'keystone_tempest_plugin',
-    'magnum_tempest_plugin',
-    'manila-tempest-plugin',
-    'mistral_tempest_tests',
-    'monasca-tempest-plugin',
-    'murano-tempest-plugin',
-    'neutron-tempest-plugin',
-    'python-tempestconf',
-    'rally-openstack',
-    'telemetry_tempest_plugin',
-    'patrole',
-    'trove_tempest_plugin',
-    'vitrage-tempest-plugin',
-    'watcher-tempest-plugin',
-    'zaqar_tempest_plugin',
-    'nova-mksproxy',
-    'novajoin',
-    'tempest',
     'vmtp',
 }
 
